
#define MY_DEBUG
#define REPORT_BATTERY_LEVEL
#define MY_RADIO_RF24
//#define MY_NODE_ID        8
#define MY_RF24_PA_LEVEL RF24_PA_MAX

#include <MySensors.h>  

#define CHILD_ID_HUM  0
#define CHILD_ID_TEMP 1
#define CHILD_ID_VCC  2

static bool metric = 0;

static const uint64_t UPDATE_INTERVAL = 60000;

#include <SI7021.h>
static SI7021 sensor;

#define PIN_NCP1400       2
#define PIN_LED           3
bool low_power = false;
float voltage;

#ifdef REPORT_BATTERY_LEVEL
#include <Vcc.h>
static uint8_t oldBatteryPcnt = 200;
const float VccMin        = 1.8;
const float VccMax        = 2.0*1.6;
const float VccCorrection = 1.0;
static Vcc vcc(VccCorrection); 
#endif

static MyMessage msgHum( CHILD_ID_HUM,  V_HUM );
static MyMessage msgTemp(CHILD_ID_TEMP, V_TEMP);
static MyMessage msgVcc( CHILD_ID_VCC, V_VOLTAGE);

void before(){
  voltage = vcc.Read_Volts();
  if( voltage < 1.8 )low_power = true;
  pinMode(PIN_NCP1400,OUTPUT);
  digitalWrite(PIN_NCP1400,HIGH);
}

void presentation()  
{ 
  sendSketchInfo("TemperatureAndHumidity", "1.0");
  present(CHILD_ID_HUM, S_HUM,   "Humidity");
  present(CHILD_ID_TEMP, S_TEMP, "Temperature");
  present(CHILD_ID_VCC, S_MULTIMETER,"mV");
  metric = getControllerConfig().isMetric;
}

void setup()
{
  {
    Serial.println(F("Sensor not detected!"));
    delay(5000);
  }
}


void loop()      
{
  voltage = vcc.Read_Volts();
  digitalWrite(PIN_NCP1400,HIGH);
  if( voltage < 1.8 )low_power = true;
  const float temperature = float( metric ? sensor.getCelsiusHundredths() : sensor.getFahrenheitHundredths() ) / 100.0;
  const float humidity    = float( sensor.getHumidityBasisPoints() ) / 100.0;
  const int batteryPcnt = voltage*100/VccMax;
  #ifdef MY_DEBUG
  Serial.print(F("Temp "));
  Serial.print(temperature);
  Serial.print(metric ? 'C' : 'F');
  Serial.print(F("\tHum "));
  Serial.println(humidity);
  Serial.print(F("Vbat "));
  Serial.print(voltage);
  Serial.print(F("\tPerc "));
  Serial.println(batteryPcnt);
  #endif

  digitalWrite(PIN_LED,HIGH); //Включаем светодиод
  send(msgTemp.set(temperature, 2));
  send(msgHum.set(humidity, 2));
  send(msgVcc.set(voltage,2)); //Посылаем значение VCC
  sendBatteryLevel(batteryPcnt);
  digitalWrite(PIN_LED,LOW); //Выключаем светодиод

  if( low_power == false )digitalWrite(PIN_NCP1400,LOW); //Выключаем стабилизатор NRF1400 
  sleep(UPDATE_INTERVAL); 
}


